@@ -1,7 +1,7 @@
 '''
 [![npm version](https://badge.fury.io/js/cdk-github.svg)](https://badge.fury.io/js/cdk-github)
 [![PyPI version](https://badge.fury.io/py/cdk-github.svg)](https://badge.fury.io/py/cdk-github)
-[![NuGet version](https://badge.fury.io/nu/CdkGithub.svg)](https://badge.fury.io/nu/CdkGithub)
+[![NuGet version](https://badge.fury.io/nu/cdkgithub.svg)](https://badge.fury.io/nu/cdkgithub)
 [![release](https://github.com/wtfjoke/cdk-github/actions/workflows/release.yml/badge.svg)](https://github.com/wtfjoke/cdk-github/actions/workflows/release.yml)
 ![cdk-constructs: Experimental](https://img.shields.io/badge/cdk--constructs-experimental-important.svg?style=for-the-badge)
 
@@ -128,9 +128,9 @@ class ActionEnvironmentSecret(
         environment: builtins.str,
         github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
         repository_name: builtins.str,
-        repository_owner: builtins.str,
         repository_secret_name: builtins.str,
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
+        repository_owner: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param scope: -
@@ -138,9 +138,9 @@ class ActionEnvironmentSecret(
         :param environment: (experimental) The GithHub environment name which the secret should be stored in.
         :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
         :param repository_name: (experimental) The GitHub repository name.
-        :param repository_owner: (experimental) The GitHub repository owner.
         :param repository_secret_name: (experimental) The GitHub secret name to be stored.
         :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
+        :param repository_owner: (experimental) The GitHub repository owner. Default: - user account which owns the token
 
         :stability: experimental
         '''
@@ -148,9 +148,9 @@ class ActionEnvironmentSecret(
             environment=environment,
             github_token_secret=github_token_secret,
             repository_name=repository_name,
-            repository_owner=repository_owner,
             repository_secret_name=repository_secret_name,
             source_secret=source_secret,
+            repository_owner=repository_owner,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -163,9 +163,9 @@ class ActionEnvironmentSecret(
         "environment": "environment",
         "github_token_secret": "githubTokenSecret",
         "repository_name": "repositoryName",
-        "repository_owner": "repositoryOwner",
         "repository_secret_name": "repositorySecretName",
         "source_secret": "sourceSecret",
+        "repository_owner": "repositoryOwner",
     },
 )
 class ActionEnvironmentSecretProps:
@@ -175,17 +175,17 @@ class ActionEnvironmentSecretProps:
         environment: builtins.str,
         github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
         repository_name: builtins.str,
-        repository_owner: builtins.str,
         repository_secret_name: builtins.str,
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
+        repository_owner: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param environment: (experimental) The GithHub environment name which the secret should be stored in.
         :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
         :param repository_name: (experimental) The GitHub repository name.
-        :param repository_owner: (experimental) The GitHub repository owner.
         :param repository_secret_name: (experimental) The GitHub secret name to be stored.
         :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
+        :param repository_owner: (experimental) The GitHub repository owner. Default: - user account which owns the token
 
         :stability: experimental
         '''
@@ -193,10 +193,11 @@ class ActionEnvironmentSecretProps:
             "environment": environment,
             "github_token_secret": github_token_secret,
             "repository_name": repository_name,
-            "repository_owner": repository_owner,
             "repository_secret_name": repository_secret_name,
             "source_secret": source_secret,
         }
+        if repository_owner is not None:
+            self._values["repository_owner"] = repository_owner
 
     @builtins.property
     def environment(self) -> builtins.str:
@@ -228,16 +229,6 @@ class ActionEnvironmentSecretProps:
         assert result is not None, "Required property 'repository_name' is missing"
         return typing.cast(builtins.str, result)
 
-    @builtins.property
-    def repository_owner(self) -> builtins.str:
-        '''(experimental) The GitHub repository owner.
-
-        :stability: experimental
-        '''
-        result = self._values.get("repository_owner")
-        assert result is not None, "Required property 'repository_owner' is missing"
-        return typing.cast(builtins.str, result)
-
     @builtins.property
     def repository_secret_name(self) -> builtins.str:
         '''(experimental) The GitHub secret name to be stored.
@@ -258,6 +249,17 @@ class ActionEnvironmentSecretProps:
         assert result is not None, "Required property 'source_secret' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
 
+    @builtins.property
+    def repository_owner(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The GitHub repository owner.
+
+        :default: - user account which owns the token
+
+        :stability: experimental
+        '''
+        result = self._values.get("repository_owner")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -286,27 +288,27 @@ class ActionSecret(
         *,
         github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
         repository_name: builtins.str,
-        repository_owner: builtins.str,
         repository_secret_name: builtins.str,
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
+        repository_owner: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
         :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
         :param repository_name: (experimental) The GitHub repository name.
-        :param repository_owner: (experimental) The GitHub repository owner.
         :param repository_secret_name: (experimental) The GitHub secret name to be stored.
         :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
+        :param repository_owner: (experimental) The GitHub repository owner. Default: - user account which owns the token
 
         :stability: experimental
         '''
         props = ActionSecretProps(
             github_token_secret=github_token_secret,
             repository_name=repository_name,
-            repository_owner=repository_owner,
             repository_secret_name=repository_secret_name,
             source_secret=source_secret,
+            repository_owner=repository_owner,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -318,9 +320,9 @@ class ActionSecret(
     name_mapping={
         "github_token_secret": "githubTokenSecret",
         "repository_name": "repositoryName",
-        "repository_owner": "repositoryOwner",
         "repository_secret_name": "repositorySecretName",
         "source_secret": "sourceSecret",
+        "repository_owner": "repositoryOwner",
     },
 )
 class ActionSecretProps:
@@ -329,26 +331,27 @@ class ActionSecretProps:
         *,
         github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
         repository_name: builtins.str,
-        repository_owner: builtins.str,
         repository_secret_name: builtins.str,
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
+        repository_owner: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
         :param repository_name: (experimental) The GitHub repository name.
-        :param repository_owner: (experimental) The GitHub repository owner.
         :param repository_secret_name: (experimental) The GitHub secret name to be stored.
         :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
+        :param repository_owner: (experimental) The GitHub repository owner. Default: - user account which owns the token
 
         :stability: experimental
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "github_token_secret": github_token_secret,
             "repository_name": repository_name,
-            "repository_owner": repository_owner,
             "repository_secret_name": repository_secret_name,
             "source_secret": source_secret,
         }
+        if repository_owner is not None:
+            self._values["repository_owner"] = repository_owner
 
     @builtins.property
     def github_token_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
@@ -370,16 +373,6 @@ class ActionSecretProps:
         assert result is not None, "Required property 'repository_name' is missing"
         return typing.cast(builtins.str, result)
 
-    @builtins.property
-    def repository_owner(self) -> builtins.str:
-        '''(experimental) The GitHub repository owner.
-
-        :stability: experimental
-        '''
-        result = self._values.get("repository_owner")
-        assert result is not None, "Required property 'repository_owner' is missing"
-        return typing.cast(builtins.str, result)
-
     @builtins.property
     def repository_secret_name(self) -> builtins.str:
         '''(experimental) The GitHub secret name to be stored.
@@ -400,6 +393,17 @@ class ActionSecretProps:
         assert result is not None, "Required property 'source_secret' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
 
+    @builtins.property
+    def repository_owner(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The GitHub repository owner.
+
+        :default: - user account which owns the token
+
+        :stability: experimental
+        '''
+        result = self._values.get("repository_owner")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
